#!/bin/bash
# Copyright 2016 Michal Žejdl
# snmpget enterprises.776 OID(s) and store to RRD

confdir=$(dirname $0)/../..
config=$confdir/defaults.sh
test -f $config || exit
. $config

functions=$coredir/snmp/functions.sh
test -f $functions || exit
. $functions

address=$1
agent=$2

# a new file descriptor to prevent pipe from closing
exec 3> $mysqlwpipe

# group write permissions for rrdcached
umask 002

rrdstep=$snmpinterval
rrdheartbeat=$((2 * rrdstep))
rraxff=0.5
rrathirtym=$((30 * 60 / rrdstep))
rratwoh=$((4 * rrathirtym))
rraday=$((12 * rratwoh))
rraweek=$((7 * rraday))
rrarows=600

rrddestdir=$rrddir/snmpagent/$agent/Telindus
test -d "$rrddestdir" || mkdir -p "$rrddestdir" || exit

# debugging
#echo "$(date '+%F %T') $(basename $0) address: $address"

for linePair in 1 2; do

	index=$((linePair - 1))
	
	# debugging
	#echo "$(date '+%F %T') linePair=$linePair index=$index"

	oldifs=$IFS
	# one line = one array element; and focus only on the first line
	IFS=$'\n'
	# no retry (-r 0), do not resend request if OID is missing (-Cf), exit on error
	result=($(snmpget -m '' -v 1 -r 0 -c $snmprcommunity -Cf -Onqt $address \
	.1.3.6.1.4.1.776.1060.742.12.22.1.1.16777216.900$index \
	.1.3.6.1.4.1.776.1060.742.12.22.1.1.33554432.900$index \
	.1.3.6.1.4.1.776.1060.742.12.26.1.1.16777216.900$index \
	))
	
	snmpget_status=$?
	# leave if something goes wrong
	test $snmpget_status -eq 0 || continue
	
	IFS=$oldifs
	
	lineAttenuation=0
	signalNoise=0
	codeViolations=0

	# ugly sanitizing
	for ((oid_row = 0; oid_row < ${#result[@]}; oid_row++)); do
		case ${result[oid_row]::49} in
		.1.3.6.1.4.1.776.1060.742.12.22.1.1.16777216.900$index)
			lineAttenuation=${result[$oid_row]#.1.3.6.1.4.1.776.1060.742.12.22.1.1.16777216.900$index }
			is_natural_number "$lineAttenuation" || lineAttenuation=0
			;;
		.1.3.6.1.4.1.776.1060.742.12.22.1.1.33554432.900$index)
			signalNoise=${result[$oid_row]#.1.3.6.1.4.1.776.1060.742.12.22.1.1.33554432.900$index }
			is_natural_number "$signalNoise" || signalNoise=0
			;;
		.1.3.6.1.4.1.776.1060.742.12.26.1.1.16777216.900$index)
			codeViolations=${result[$oid_row]#.1.3.6.1.4.1.776.1060.742.12.26.1.1.16777216.900$index }
			is_natural_number "$codeViolations" || codeViolations=0
			;;
		esac
	done
	
	# debugging
	#echo "$(date '+%F %T') $(basename $0) lineAttenuation=$lineAttenuation signalNoise=$signalNoise, codeViolations=$codeViolations"
	#continue
	
	rrdfile="$rrddestdir/linePair$linePair.rrd"
	
	# --start is not necessary
	test -f "$rrdfile" || rrdtool create "$rrdfile" --step $rrdstep \
DS:lineAttenuation:GAUGE:$rrdheartbeat:0:U \
DS:signalNoise:GAUGE:$rrdheartbeat:0:U \
DS:codeViolations:COUNTER:$rrdheartbeat:0:U \
RRA:AVERAGE:$rraxff:1:$rrarows \
RRA:AVERAGE:$rraxff:$rrathirtym:$rrarows \
RRA:AVERAGE:$rraxff:$rratwoh:$rrarows \
RRA:AVERAGE:$rraxff:$rraday:$rrarows \
RRA:AVERAGE:$rraxff:$rraweek:$rrarows \
RRA:MIN:$rraxff:1:$rrarows \
RRA:MIN:$rraxff:$rrathirtym:$rrarows \
RRA:MIN:$rraxff:$rratwoh:$rrarows \
RRA:MIN:$rraxff:$rraday:$rrarows \
RRA:MIN:$rraxff:$rraweek:$rrarows \
RRA:MAX:$rraxff:1:$rrarows \
RRA:MAX:$rraxff:$rrathirtym:$rrarows \
RRA:MAX:$rraxff:$rratwoh:$rrarows \
RRA:MAX:$rraxff:$rraday:$rrarows \
RRA:MAX:$rraxff:$rraweek:$rrarows \
RRA:LAST:$rraxff:1:$rrarows \
RRA:LAST:$rraxff:$rrathirtym:$rrarows \
RRA:LAST:$rraxff:$rratwoh:$rrarows \
RRA:LAST:$rraxff:$rraday:$rrarows \
RRA:LAST:$rraxff:$rraweek:$rrarows
	
	rrdtool update "$rrdfile" $rrdcached N:\
$lineAttenuation:\
$signalNoise:\
$codeViolations

done

# pass the exit status of the last snmp* command to the collector.sh
exit $snmpget_status
