#!/bin/bash
# Copyright 2015 - 2018 Michal Žejdl
# try to be informed about discharging APC UPSes
# args: [capacity limit [sysName to exlude [sysName to exclude [...]]]]
# input: conf, mysql table mibapc
# output: list of UPSes which upsAdvBatteryCapacity drops below the limit
# - avoid UPSes with a bad battery (0, 0)
# - avoid UPSes which are not on battery (upsBasicBatteryTimeOnBattery = 0)
# dependence: mysql

confdir=$(dirname $0)/..
config=$confdir/defaults.sh
test -f $config || exit
source $config

limit=100
test $# -ge 1 && test $1 -ge 0 -a $1 -le 100 && limit=$1

if test $# -gt 1
then
	shift
	for arg in $@
	do
		blacklist="$blacklist and sysName != '$arg'"
	done
fi

mysql -e "\
select agent, sysName, upsBasicIdentModel model, \
	from_unixtime(mibapc.time - floor(upsBasicBatteryTimeOnBattery / 100)) \
		'on battery', \
	upsAdvBatteryCapacity 'capacity [%]', \
	floor((mibapc.time + floor(upsAdvBatteryRunTimeRemaining / 100) \
		- unix_timestamp()) / 60) 'time [min]', \
	from_unixtime(floor(upsAdvBatteryRunTimeRemaining / 100) + mibapc.time) \
		poweroff \
from snmpagent join mibapc on id = agent \
where upsAdvBatteryCapacity < $limit \
	and unix_timestamp() - mibapc.time <= 3 * $snmpinterval \
	and mibapc.time + floor(upsAdvBatteryRunTimeRemaining / 100) \
		> unix_timestamp() \
	and not (upsAdvBatteryCapacity = 0 \
		and upsAdvBatteryRunTimeRemaining = 0) \
	and upsBasicBatteryTimeOnBattery > 0 \
	$blacklist \
order by poweroff" -h $dbhost -p$dbrpass -u $dbruser $dbname -t
