#!/bin/bash
# Copyright 2018 Michal Žejdl
# generate RRD graphs for Alcoma according to RRD file name (MIB node)

# at least five args are required
test $# -lt 5 && exit

rrdbasedir=$1
rrdfile=$2
outputdir=$3
starttime=$4
endtime=$5

# make the remote flush possible
cd $rrdbasedir || exit

test -d "$outputdir" || mkdir -p "$outputdir" || exit

# lazy (-z) is handy
options="-s $starttime -e $endtime -z"

# append rrdcached
test $# -gt 5 && options="$options --daemon $6"

filename=$(basename $rrdfile .rrd)

case "$filename" in
alMPODU)
	rrdtool graph \
$outputdir/alcoma-"$filename"-RXLevel-"$starttime"-"$endtime".png \
$options -t "RX-Level" -v "dB" \
DEF:dsa="$rrdfile":RXLevel:AVERAGE \
DEF:dsn="$rrdfile":RXLevel:MIN \
DEF:dsm="$rrdfile":RXLevel:MAX \
DEF:dsl="$rrdfile":RXLevel:LAST \
VDEF:dsaa=dsa,AVERAGE \
VDEF:dsnn=dsn,MINIMUM \
VDEF:dsmm=dsm,MAXIMUM \
VDEF:dsll=dsl,LAST \
TEXTALIGN:left \
LINE2:dsa#0000cc:"  " \
GPRINT:dsaa:"avg\: %6.2lf %s" \
GPRINT:dsnn:"min\: %6.2lf %s" \
GPRINT:dsmm:"max\: %6.2lf %s" \
GPRINT:dsll:"lst\: %6.2lf %s"
	rrdtool graph \
$outputdir/alcoma-"$filename"-Temperature-"$starttime"-"$endtime".png \
$options -t "Temperature" -v "°C" \
DEF:dsa="$rrdfile":Temperature:AVERAGE \
DEF:dsn="$rrdfile":Temperature:MIN \
DEF:dsm="$rrdfile":Temperature:MAX \
DEF:dsl="$rrdfile":Temperature:LAST \
VDEF:dsaa=dsa,AVERAGE \
VDEF:dsnn=dsn,MINIMUM \
VDEF:dsmm=dsm,MAXIMUM \
VDEF:dsll=dsl,LAST \
TEXTALIGN:left \
LINE2:dsa#0000cc:"  " \
GPRINT:dsaa:"avg\: %6.2lf %s" \
GPRINT:dsnn:"min\: %6.2lf %s" \
GPRINT:dsmm:"max\: %6.2lf %s" \
GPRINT:dsll:"lst\: %6.2lf %s"
	;;
alMPModem)
	rrdtool graph \
$outputdir/alcoma-"$filename"-Quality-"$starttime"-"$endtime".png \
$options -t "Quality" -v "%" \
DEF:dsa="$rrdfile":Quality:AVERAGE \
DEF:dsn="$rrdfile":Quality:MIN \
DEF:dsm="$rrdfile":Quality:MAX \
DEF:dsl="$rrdfile":Quality:LAST \
VDEF:dsaa=dsa,AVERAGE \
VDEF:dsnn=dsn,MINIMUM \
VDEF:dsmm=dsm,MAXIMUM \
VDEF:dsll=dsl,LAST \
TEXTALIGN:left \
LINE2:dsa#0000cc:"  " \
GPRINT:dsaa:"avg\: %6.2lf %s" \
GPRINT:dsnn:"min\: %6.2lf %s" \
GPRINT:dsmm:"max\: %6.2lf %s" \
GPRINT:dsll:"lst\: %6.2lf %s"
	rrdtool graph \
$outputdir/alcoma-"$filename"-SNR-"$starttime"-"$endtime".png \
$options -t "SNR" -v " " \
DEF:dsa="$rrdfile":SNR:AVERAGE \
DEF:dsn="$rrdfile":SNR:MIN \
DEF:dsm="$rrdfile":SNR:MAX \
DEF:dsl="$rrdfile":SNR:LAST \
VDEF:dsaa=dsa,AVERAGE \
VDEF:dsnn=dsn,MINIMUM \
VDEF:dsmm=dsm,MAXIMUM \
VDEF:dsll=dsl,LAST \
TEXTALIGN:left \
LINE2:dsa#0000cc:"  " \
GPRINT:dsaa:"avg\: %6.2lf %s" \
GPRINT:dsnn:"min\: %6.2lf %s" \
GPRINT:dsmm:"max\: %6.2lf %s" \
GPRINT:dsll:"lst\: %6.2lf %s"
	;;
alMPLine*)
	rrdtool graph \
$outputdir/alcoma-"$filename"-Byte-"$starttime"-"$endtime".png \
$options -t "Byte" -v "bits / sec" \
DEF:ioa="$rrdfile":ByteRX:AVERAGE \
DEF:ion="$rrdfile":ByteRX:MIN \
DEF:iom="$rrdfile":ByteRX:MAX \
DEF:iol="$rrdfile":ByteRX:LAST \
DEF:ooa="$rrdfile":ByteTX:AVERAGE \
DEF:oon="$rrdfile":ByteTX:MIN \
DEF:oom="$rrdfile":ByteTX:MAX \
DEF:ool="$rrdfile":ByteTX:LAST \
CDEF:iba=ioa,8,* \
CDEF:ibn=ion,8,* \
CDEF:ibm=iom,8,* \
CDEF:ibl=iol,8,* \
CDEF:oba=ooa,8,* \
CDEF:obn=oon,8,* \
CDEF:obm=oom,8,* \
CDEF:obl=ool,8,* \
VDEF:ibaa=iba,AVERAGE \
VDEF:ibnn=ibn,MINIMUM \
VDEF:ibmm=ibm,MAXIMUM \
VDEF:ibll=ibl,LAST \
VDEF:obaa=oba,AVERAGE \
VDEF:obnn=obn,MINIMUM \
VDEF:obmm=obm,MAXIMUM \
VDEF:obll=obl,LAST \
TEXTALIGN:left \
AREA:iba#00CC00:"RX" \
GPRINT:ibaa:"avg\: %6.2lf %s" \
GPRINT:ibnn:"min\: %6.2lf %s" \
GPRINT:ibmm:"max\: %6.2lf %s" \
GPRINT:ibll:"lst\: %6.2lf %s\l" \
LINE2:oba#0000CC:"TX" \
GPRINT:obaa:"avg\: %6.2lf %s" \
GPRINT:obnn:"min\: %6.2lf %s" \
GPRINT:obmm:"max\: %6.2lf %s" \
GPRINT:obll:"lst\: %6.2lf %s\l"
	rrdtool graph \
$outputdir/alcoma-"$filename"-Pkt-"$starttime"-"$endtime".png \
$options -t "Pkt" -v "pkts / sec" \
DEF:ica="$rrdfile":PktRX:AVERAGE \
DEF:icn="$rrdfile":PktRX:MIN \
DEF:icm="$rrdfile":PktRX:MAX \
DEF:icl="$rrdfile":PktRX:LAST \
DEF:oca="$rrdfile":PktTX:AVERAGE \
DEF:ocn="$rrdfile":PktTX:MIN \
DEF:ocm="$rrdfile":PktTX:MAX \
DEF:ocl="$rrdfile":PktTX:LAST \
VDEF:icaa=ica,AVERAGE \
VDEF:icnn=icn,MINIMUM \
VDEF:icmm=icm,MAXIMUM \
VDEF:icll=icl,LAST \
VDEF:ocaa=oca,AVERAGE \
VDEF:ocnn=ocn,MINIMUM \
VDEF:ocmm=ocm,MAXIMUM \
VDEF:ocll=ocl,LAST \
TEXTALIGN:left \
AREA:ica#00CC00:"RX" \
GPRINT:icaa:"avg\: %6.2lf %s" \
GPRINT:icnn:"min\: %6.2lf %s" \
GPRINT:icmm:"max\: %6.2lf %s" \
GPRINT:icll:"lst\: %6.2lf %s\l" \
LINE2:oca#0000CC:"TX" \
GPRINT:ocaa:"avg\: %6.2lf %s" \
GPRINT:ocnn:"min\: %6.2lf %s" \
GPRINT:ocmm:"max\: %6.2lf %s" \
GPRINT:ocll:"lst\: %6.2lf %s\l"
	;;
esac
